@@ -1,7 +1,10 @@
-/*  $Revision: 1.4 $
+/*  $Id: shrinkfile.c 7585 2006-11-21 09:37:51Z eagle $
+**
 **  Shrink files on line boundaries.
+**
 **  Written by Landon Curt Noll <chongo@toad.com>, and placed in the
 **  public domain.  Rewritten for INN by Rich Salz.
+**
 **  Usage:
 **	shrinkfile [-n] [-s size [-m maxsize]] [-v] file...
 **	-n		No writes, exit 0 if any file is too large, 1 otherwise
@@ -19,50 +22,40 @@
 **  The -n flag may be used to determine of any file is too large.  No
 **  files will be altered in this mode.
 */
-#include <stdio.h>
-#include <sys/types.h>
-#include "configdata.h"
+
+#include "config.h"
 #include "clibrary.h"
 #include <ctype.h>
 #include <errno.h>
-#include <sys/stat.h>
 #include <fcntl.h>
-#include <syslog.h>
-#include "libinn.h"
-#include "macros.h"
+#include <sys/stat.h>
 
+#include "inn/innconf.h"
+#include "inn/messages.h"
+#include "inn/libinn.h"
 
-#define MAX_SIZE	(OFFSET_T)0x7fffffff
+#define MAX_SIZE	0x7fffffffUL
 
 
-static char *program = NULL;	/* our name */
-
 /*
 **  Open a safe unique temporary file that will go away when closed.
 */
-STATIC FILE *
-OpenTemp()
+static FILE *
+OpenTemp(void)
 {
     FILE	*F;
-    char	buff[SMBUF];
-    int		i;
+    char        *filename;
+    int		fd;
 
-    /* Get filename. */
-    (void)sprintf(buff, "%s/shrinkXXXXXX", innconf->pathtmp);
-    (void)mktemp(buff);
-
-    /* Open the file. */
-    if ((i = open(buff, O_RDWR | O_CREAT | O_EXCL | O_TRUNC, 0600)) < 0) {
-	(void)fprintf(stderr, "%s: Can't make temporary file, %s\n",
-		program, strerror(errno));
-	exit(1);
-    }
-    if ((F = fdopen(i, "w+")) == NULL) {
-	(void)fprintf(stderr,
-	  "%s: Can't fdopen %d, %s\n", program, i, strerror(errno));
-	exit(1);
-    }
-    (void)unlink(buff);
+    filename = concatpath(innconf->pathtmp, "shrinkXXXXXX");
+    fd = mkstemp(filename);
+    if (fd < 0)
+        sysdie("cannot create temporary file");
+    F = fdopen(fd, "w+");
+    if (F == NULL)
+        sysdie("cannot fdopen %s", filename);
+    unlink(filename);
+    free(filename);
     return F;
 }
 
@@ -70,24 +63,21 @@ OpenTemp()
 /*
 **  Does file end with \n?  Assume it does on I/O error, to avoid doing I/O.
 */
-STATIC int
-EndsWithNewline(F)
-    FILE	*F;
+static int
+EndsWithNewline(FILE *F)
 {
     int		c;
 
-    if (fseek(F, (OFFSET_T)1, SEEK_END) < 0) {
-	(void)fprintf(stderr, "%s: Can't seek to end of file, %s\n",
-		program, strerror(errno));
-	return TRUE;
+    if (fseeko(F, 1, SEEK_END) < 0) {
+        syswarn("cannot seek to end of file");
+	return true;
     }
 
     /* return the actual character or EOF */
     if ((c = fgetc(F)) == EOF) {
 	if (ferror(F))
-	    (void)fprintf(stderr, "%s: Can't read last byte, %s\n",
-		    program, strerror(errno));
-	return TRUE;
+            syswarn("cannot read last byte");
+	return true;
     }
     return c == '\n';
 }
@@ -96,186 +86,169 @@ EndsWithNewline(F)
 /*
 **  Add a newline to location of a file.
 */
-STATIC BOOL
-AppendNewline(name)
-    char	*name;
+static bool
+AppendNewline(char *name)
 {
     FILE	*F;
 
     if ((F = xfopena(name)) == NULL) {
-	(void)fprintf(stderr,
-	  "%s: Can't add newline, %s\n", program, strerror(errno));
-	return FALSE;
+        syswarn("cannot add newline");
+	return false;
     }
 
     if (fputc('\n', F) == EOF
      || fflush(F) == EOF
      || ferror(F)
      || fclose(F) == EOF) {
-	(void)fprintf(stderr,
-	  "%s: Can't add newline, %s\n", program, strerror(errno));
-	return FALSE;
+        syswarn("cannot add newline");
+	return false;
     }
 
-    return TRUE;
+    return true;
 }
 
 /*
 **  Just check if it is too big
 */
-STATIC BOOL
-TooBig(F, maxsize)
-    FILE	*F;
-    OFFSET_T	maxsize;
+static bool
+TooBig(FILE *F, off_t maxsize)
 {
     struct stat	Sb;
 
     /* Get the file's size. */
     if (fstat((int)fileno(F), &Sb) < 0) {
-	(void)fprintf(stderr,
-	  "%s: Can't fstat, %s\n", program, strerror(errno));
-	return FALSE;
+        syswarn("cannot fstat");
+	return false;
     }
 
-    /* return TRUE if too large */
-    return (maxsize > Sb.st_size ? FALSE : TRUE);
+    /* return true if too large */
+    return (maxsize > Sb.st_size ? false : true);
 }
 
 /*
 **  This routine does all the work.
 */
-STATIC BOOL
-Process(F, name, size, maxsize, Changedp)
-    FILE	*F;
-    char	*name;
-    OFFSET_T	size;
-    OFFSET_T	maxsize;
-    BOOL	*Changedp;
+static bool
+Process(FILE *F, char *name, off_t size, off_t maxsize, bool *Changedp)
 {
-    OFFSET_T	len;
+    off_t	len;
     FILE	*tmp;
     struct stat	Sb;
     char	buff[BUFSIZ + 1];
     int		c;
-    int		i;
+    size_t	i;
+    bool	err;
 
     /* Get the file's size. */
     if (fstat((int)fileno(F), &Sb) < 0) {
-	(void)fprintf(stderr,
-	  "%s: Can't fstat, %s\n", program, strerror(errno));
-	return FALSE;
+        syswarn("cannot fstat");
+	return false;
     }
     len = Sb.st_size;
 
     /* Process a zero size request. */
     if (size == 0 && len > maxsize) {
 	if (len > 0) {
-	    (void)fclose(F);
+	    fclose(F);
 	    if ((F = fopen(name, "w")) == NULL) {
-		(void)fprintf(stderr,
-		  "%s: Can't overwrite, %s\n", program, strerror(errno));
-		return FALSE;
+                syswarn("cannot overwrite");
+		return false;
 	    }
-	    (void)fclose(F);
-	    *Changedp = TRUE;
+	    fclose(F);
+	    *Changedp = true;
 	}
-	return TRUE;
+	return true;
     }
 
     /* See if already small enough. */
     if (len <= maxsize) {
 	/* Newline already present? */
 	if (EndsWithNewline(F)) {
-	    (void)fclose(F);
-	    return TRUE;
+	    fclose(F);
+	    return true;
 	}
 
 	/* No newline, add it if it fits. */
 	if (len < size - 1) {
-	    (void)fclose(F);
-	    *Changedp = TRUE;
+	    fclose(F);
+	    *Changedp = true;
 	    return AppendNewline(name);
 	}
     }
     else if (!EndsWithNewline(F)) {
 	if (!AppendNewline(name)) {
-	    (void)fclose(F);
-	    return FALSE;
+	    fclose(F);
+	    return false;
 	}
     }
 
     /* We now have a file that ends with a newline that is bigger than
      * we want.  Starting from {size} bytes from end, move forward
      * until we get a newline. */
-    if (fseek(F, -size, SEEK_END) < 0) {
-	(void)fprintf(stderr,
-	  "%s: Can't fseek, %s\n", program, strerror(errno));
-	(void)fclose(F);
-	return FALSE;
+    if (fseeko(F, -size, SEEK_END) < 0) {
+        syswarn("cannot fseeko");
+	fclose(F);
+	return false;
     }
 
     while ((c = getc(F)) != '\n')
 	if (c == EOF) {
-	    (void)fprintf(stderr,
-	      "%s: Can't read, %s\n", program, strerror(errno));
-	    (void)fclose(F);
-	    return FALSE;
+            syswarn("cannot read");
+	    fclose(F);
+	    return false;
 	}
 
     /* Copy rest of file to temp. */
     tmp = OpenTemp();
-    while ((i = fread((POINTER)buff, (SIZE_T)1, (SIZE_T)sizeof buff, F)) > 0)
-	if (fwrite((POINTER)buff, (SIZE_T)1, (SIZE_T)i, tmp) != i) {
-	    i = -1;
+    err = false;
+    while ((i = fread(buff, 1, sizeof buff, F)) > 0)
+	if (fwrite(buff, 1, i, tmp) != i) {
+	    err = true;
 	    break;
 	}
-    if (i < 0) {
-	(void)fprintf(stderr, 
-	  "%s: Can't copy to temp file, %s\n", program, strerror(errno));
-	(void)fclose(F);
-	(void)fclose(tmp);
-	return FALSE;
+    if (err) {
+        syswarn("cannot copy to temporary file");
+	fclose(F);
+	fclose(tmp);
+	return false;
     }
 
     /* Now copy temp back to original file. */
-    (void)fclose(F);
+    fclose(F);
     if ((F = fopen(name, "w")) == NULL) {
-	(void)fprintf(stderr,
-	  "%s: Can't overwrite, %s\n", program, strerror(errno));
-	(void)fclose(tmp);
-	return FALSE;
+        syswarn("cannot overwrite file");
+	fclose(tmp);
+	return false;
     }
-    (void)fseek(tmp, (OFFSET_T)0, SEEK_SET);
+    fseeko(tmp, 0, SEEK_SET);
 
-    while ((i = fread((POINTER)buff, (SIZE_T)1, (SIZE_T)sizeof buff, tmp)) > 0)
-	if (fwrite((POINTER)buff, (SIZE_T)1, (SIZE_T)i, F) != i) {
-	    i = -1;
+    while ((i = fread(buff, 1, sizeof buff, tmp)) > 0)
+	if (fwrite(buff, 1, i, F) != i) {
+	    err = true;
 	    break;
 	}
-    if (i < 0) {
-	(void)fprintf(stderr,
-	  "%s: Can't overwrite file, %s\n", program, strerror(errno));
-	(void)fclose(F);
-	(void)fclose(tmp);
-	return FALSE;
+    if (err) {
+        syswarn("cannot overwrite file");
+	fclose(F);
+	fclose(tmp);
+	return false;
     }
 
-    (void)fclose(F);
-    (void)fclose(tmp);
-    *Changedp = TRUE;
-    return TRUE;
+    fclose(F);
+    fclose(tmp);
+    *Changedp = true;
+    return true;
 }
 
 
 /*
 **  Convert size argument to numeric value.  Return -1 on error.
 */
-STATIC OFFSET_T
-ParseSize(p)
-    char	*p;
+static off_t
+ParseSize(char *p)
 {
-    OFFSET_T	scale;
-    long	str_num;
+    off_t	scale;
+    unsigned long	str_num;
     char	*q;
 
     /* Skip leading spaces */
@@ -308,12 +281,10 @@ ParseSize(p)
     }
 
     /* Convert string to number. */
-    if (sscanf(p, "%ld", &str_num) != 1)
+    if (sscanf(p, "%lud", &str_num) != 1)
 	return -1;
-    if (str_num > MAX_SIZE / scale) {
-	(void)fprintf(stderr, "%s: Size is too big\n", program);
-	exit(1);
-    }
+    if (str_num > MAX_SIZE / scale)
+        die("size is too big");
 
     return scale * str_num;
 }
@@ -322,38 +293,37 @@ ParseSize(p)
 /*
 **  Print usage message and exit.
 */
-STATIC NORETURN
-Usage()
+static void
+Usage(void)
 {
-    (void)fprintf(stderr, "Usage: %s [-n] [ -m maxsize ] [-s size] [-v] file...\n", program);
+    fprintf(stderr,
+            "Usage: shrinkfile [-n] [ -m maxsize ] [-s size] [-v] file...");
     exit(1);
 }
 
 
 int
-main(ac, av)
-    int		ac;
-    char	*av[];
+main(int ac, char *av[])
 {
-    BOOL	Changed;
-    BOOL	Verbose;
-    BOOL	no_op;
+    bool	Changed;
+    bool	Verbose;
+    bool	no_op;
     FILE	*F;
     char	*p;
     int		i;
-    OFFSET_T	size = (OFFSET_T)0;
-    OFFSET_T	maxsize = (OFFSET_T)0;
+    off_t	size = 0;
+    off_t	maxsize = 0;
 
-    /* First thing, set up logging and our identity. */
-    openlog("shrinkfile", L_OPENLOG_FLAGS | LOG_PID, LOG_INN_PROG);
+    /* First thing, set up our identity. */
+    message_program_name = "shrinkfile";
 
     /* Set defaults. */
-    program = av[0];
-    Verbose = FALSE;
-    no_op = FALSE;
-    (void)umask(NEWSUMASK);
+    Verbose = false;
+    no_op = false;
+    umask(NEWSUMASK);
 
-    if (ReadInnConf() < 0) exit(1);
+    if (!innconf_read(NULL))
+        exit(1);
 
     /* Parse JCL. */
     while ((i = getopt(ac, av, "m:s:vn")) != EOF)
@@ -362,7 +332,7 @@ main(ac, av)
 	    Usage();
 	    /* NOTREACHED */
 	case 'n':
-	    no_op = TRUE;
+	    no_op = true;
 	    break;
 	case 'm':
 	    if ((maxsize = ParseSize(optarg)) < 0)
@@ -373,7 +343,7 @@ main(ac, av)
 		Usage();
 	    break;
 	case 'v':
-	    Verbose = TRUE;
+	    Verbose = true;
 	    break;
 	}
     if (maxsize < size) {
@@ -386,8 +356,7 @@ main(ac, av)
 
     while ((p = *av++) != NULL) {
 	if ((F = fopen(p, "r")) == NULL) {
-	    (void)fprintf(stderr,
-	      "%s: Can't open %s, %s\n", program, p, strerror(errno));
+            syswarn("cannot open %s", p);
 	    continue;
 	}
 
@@ -397,22 +366,22 @@ main(ac, av)
 	    /* check if too big and exit zero if it is */
 	    if (TooBig(F, maxsize)) {
 		if (Verbose)
-		    (void)printf("%s: %s is too large\n", program, p);
+                    notice("%s is too large", p);
 		exit(0);
 		/* NOTREACHED */
 	    }
 
 	/* no -n, do some real work */
 	} else {
-	    Changed = FALSE;
+	    Changed = false;
 	    if (!Process(F, p, size, maxsize, &Changed))
-		(void)fprintf(stderr, "%s: Can't shrink %s\n", program, p);
+                syswarn("cannot shrink %s", p);
 	    else if (Verbose && Changed)
-		(void)printf("%s: Shrunk %s\n", program, p);
+                notice("shrunk %s", p);
 	}
     }
     if (no_op && Verbose) {
-	(void)printf("%s: did not find a file that was too large\n", program);
+        notice("did not find a file that was too large");
     }
 
     /* if -n, then exit non-zero to indicate no file too big */
