@@ -1,4 +1,4 @@
-/*  $Id: sys2nf.c 8231 2008-12-14 16:53:54Z iulius $
+/*  $Id: sys2nf.c 9024 2010-03-21 16:49:30Z iulius $
 **
 **  Read a C news "sys" file and split it up into a set of INN
 **  newsfeeds entries.  Also works with B news.
@@ -15,8 +15,8 @@
 
 #include "inn/innconf.h"
 #include "inn/libinn.h"
+#include "inn/nntp.h"
 #include "inn/paths.h"
-#include "nntp.h"
 
 #define TEMPFILE	":tmp"
 static char		**Groups;
@@ -87,7 +87,7 @@ ReadSys(sys)
 		break;
 	    }
 	    if (*p == '\\' && p[1] == '\n')
-		while (*++p && CTYPE(isspace, *p))
+		while (*++p && isspace((unsigned char) *p))
 		    continue;
 	    else
 		*to++ = *p++;
@@ -184,7 +184,7 @@ DoSub(F, p)
     len = 8 + 1 + 2;
     do {
         for (matched = false, i = 0; i < ARRAY_SIZE(distributions); i++)
-            if (strcmp(s, distributions[i]) == 0) {
+            if (strcasecmp(s, distributions[i]) == 0) {
                 matched = true;
                 break;
             }
@@ -210,7 +210,7 @@ DoSub(F, p)
 	    s++;
 	}
 
-	SawAll = (strcmp(s, "all") == 0);
+	SawAll = (strcasecmp(s, "all") == 0);
 	if (SawAll)
 	    s = SawBang ? "*" : "*,!control,!control.*";
 	len += strlen(s);
