@@ -1,4 +1,4 @@
-/* $Id: hisinterface.h 6504 2003-10-20 21:47:56Z rra $
+/* $Id: hisinterface.h 8575 2009-08-18 13:53:54Z iulius $
 **
 ** Interface to history API modules
 */
@@ -31,7 +31,7 @@ typedef struct hismethod {
     bool (*walk)(void *, const char *, void *,
 		 bool (*)(void *, time_t, time_t, time_t,
 			  const struct token *));
-    bool (*remember)(void *, const char *, time_t);
+    bool (*remember)(void *, const char *, time_t, time_t);
     bool (*ctl)(void *, int, void *);
 } HIS_METHOD;
 
