@@ -1,4 +1,4 @@
-/* $Id: xmalloc.c 5379 2002-03-31 21:45:12Z rra $ */
+/* $Id: xmalloc.c 9248 2011-07-17 18:04:50Z iulius $ */
 /* Test suite for xmalloc and family. */
 
 #include "config.h"
@@ -14,7 +14,7 @@
 #include <sys/resource.h>
 
 #include "inn/messages.h"
-#include "libinn.h"
+#include "inn/libinn.h"
 
 /* A customized error handler for checking xmalloc's support of them.
    Prints out the error message and exits with status 1. */
@@ -144,6 +144,63 @@ test_calloc(size_t size)
     return 1;
 }
 
+/* Test asprintf with a large string (essentially using it as strdup).
+   Returns true if successful, false otherwise. */
+static int
+test_asprintf(size_t size)
+{
+    char *copy, *string;
+    size_t i;
+
+    string = xmalloc(size);
+    memset(string, 42, size - 1);
+    string[size - 1] = '\0';
+    xasprintf(&copy, "%s", string);
+    free(string);
+    for (i = 0; i < size - 1; i++)
+        if (copy[i] != 42)
+            return 0;
+    if (copy[size - 1] != '\0')
+        return 0;
+    free(copy);
+    return 1;
+}
+
+/* Wrapper around vasprintf to do the va_list stuff. */
+static int
+xvasprintf_wrapper(char **strp, const char *format, ...)
+{
+    va_list args;
+    int status;
+
+    va_start(args, format);
+    status = xvasprintf(strp, format, args);
+    va_end(args);
+    return status;
+}
+
+/* Test vasprintf with a large string (essentially using it as strdup).
+   Returns true if successful, false otherwise. */
+static int
+test_vasprintf(size_t size)
+{
+    char *copy, *string;
+    size_t i;
+
+    string = xmalloc(size);
+    memset(string, 42, size - 1);
+    string[size - 1] = '\0';
+    xvasprintf_wrapper(&copy, "%s", string);
+    free(string);
+    for (i = 0; i < size - 1; i++)
+        if (copy[i] != 42)
+            return 0;
+    if (copy[size - 1] != '\0')
+        return 0;
+    free(copy);
+    return 1;
+}
+
 /* Take the amount of memory to allocate in bytes as a command-line argument
    and call test_malloc with that amount of memory. */
 int
@@ -187,7 +244,7 @@ main(int argc, char *argv[])
 
     /* If the code is capitalized, install our customized error handler. */
     code = argv[1][0];
-    if (isupper(code)) {
+    if (isupper((unsigned char) code)) {
         xmalloc_error_handler = test_handler;
         code = tolower(code);
     }
@@ -196,7 +253,7 @@ main(int argc, char *argv[])
        2, so that if it unexpectedly succeeds, we exit with a status
        indicating that the test should be skipped. */
     max = size;
-    if (code == 's' || code == 'n')
+    if (code == 's' || code == 'n' || code == 'a' || code == 'v')
         max *= 2;
     if (limit > 0 && max > limit)
         willfail = 2;
@@ -207,6 +264,8 @@ main(int argc, char *argv[])
     case 'r': exit(test_realloc(size) ? willfail : 1);
     case 's': exit(test_strdup(size) ? willfail : 1);
     case 'n': exit(test_strndup(size) ? willfail : 1);
+    case 'a': exit(test_asprintf(size) ? willfail : 1);
+    case 'v': exit(test_vasprintf(size) ? willfail : 1);
     default:
         die("Unknown mode %c", argv[1][0]);
         break;
